@@ -1,3 +1,8 @@
+# This is a sample file for testing.
+"""
+This is a sample file for testing.
+"""
+
 import sys
 from dataclasses import dataclass
 from typing import (
@@ -62,6 +67,10 @@ class KlassWithCommentAndDecorator:
     pass
 
 
+class_value1 = "default1"
+class_value2 = "default2"
+
+
 class KlassWithMember:
     value: StrAlias
     meta: KlassWithMetaKlass
@@ -72,12 +81,17 @@ class KlassWithFunction(KlassWithComment1):
         pass
 
 
+if __name__ == "__main__":
+    print("Hello, World!")
+    sys.exit(0)
+
+
 def _function_start_with_underscore(klass: KlassWithComment2):
     print(klass)
 
 
 """
-    - Do not delete this comment for function_with_comment1
+- Do not delete this comment for function_with_comment1
 """
 
 
@@ -106,6 +120,9 @@ def function_with_decorator():
     pass
 
 
+def_value = 1
+
+
 # this comment for function_with_comment_and_decorator
 @staticmethod
 def function_with_comment_and_decorator():
@@ -114,8 +131,3 @@ def function_with_comment_and_decorator():
 
 async def function_with_async():
     pass
-
-
-if __name__ == "__main__":
-    print("Hello, World!")
-    sys.exit(0)
\ No newline at end of file
